@@ -225,6 +225,8 @@ from keystoneauth1 import loading
 from keystoneauth1.loading import session as session_loading
 from keystoneclient.common import cms
 from keystoneclient import exceptions as ksc_exceptions
+import oslo_cache
+from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 import webob.dec
@@ -245,6 +247,7 @@ from keystonemiddleware.i18n import _
 
 _LOG = logging.getLogger(__name__)
 _CACHE_INVALID_INDICATOR = 'invalid'
+oslo_cache.configure(cfg.CONF)
 
 
 AUTH_TOKEN_OPTS = [
@@ -306,10 +309,10 @@ class BaseAuthProtocol(object):
                                    perform.
     """
 
-    # NOTE(jamielennox): Default to True and remove in Pike. This is a
+    # NOTE(jamielennox): Default to True and remove in Queens. This is a
     # compatibility flag to allow passing **kwargs to fetch_token(). This
     # is basically to allow compatibility with keystone's override. We will
-    # assume all subclasses are ok with this being True in the Pike release.
+    # assume all subclasses are ok with this being True in the Queens release.
     kwargs_to_fetch_token = False
 
     def __init__(self,
@@ -430,12 +433,15 @@ class BaseAuthProtocol(object):
 
     def _do_fetch_token(self, token, **kwargs):
         """Helper method to fetch a token and convert it into an AccessInfo."""
+        # NOTE(edmondsw): strip the token to remove any whitespace that may
+        # have been passed along in the header per bug 1689468
+        token = token.strip()
         if self.kwargs_to_fetch_token:
             data = self.fetch_token(token, **kwargs)
         else:
             m = _('Implementations of auth_token must set '
                   'kwargs_to_fetch_token this will be the required and '
-                  'assumed in Pike.')
+                  'assumed in Queens.')
             warnings.warn(m)
             data = self.fetch_token(token)
 
@@ -553,6 +559,8 @@ class AuthProtocol(BaseAuthProtocol):
                                    _base.AUTHTOKEN_GROUP,
                                    list_opts(),
                                    conf)
+        if self._conf.oslo_conf_obj != cfg.CONF:
+            oslo_cache.configure(self._conf.oslo_conf_obj)
 
         token_roles_required = self._conf.get('service_token_roles_required')
 
@@ -580,17 +588,20 @@ class AuthProtocol(BaseAuthProtocol):
         self._session = self._create_session()
         self._identity_server = self._create_identity_server()
 
-        self._auth_uri = self._conf.get('auth_uri')
-        if not self._auth_uri:
+        self._www_authenticate_uri = self._conf.get('www_authenticate_uri')
+        if not self._www_authenticate_uri:
+            self._www_authenticate_uri = self._conf.get('auth_uri')
+        if not self._www_authenticate_uri:
             self.log.warning(
-                'Configuring auth_uri to point to the public identity '
-                'endpoint is required; clients may not be able to '
+                'Configuring www_authenticate_uri to point to the public '
+                'identity endpoint is required; clients may not be able to '
                 'authenticate against an admin endpoint')
 
             # FIXME(dolph): drop support for this fallback behavior as
             # documented in bug 1207517.
 
-            self._auth_uri = self._identity_server.auth_uri
+            self._www_authenticate_uri = \
+                self._identity_server.www_authenticate_uri
 
         self._signing_directory = _signing_dir.SigningDirectory(
             directory_name=self._conf.get('signing_dir'), log=self.log)
@@ -684,7 +695,7 @@ class AuthProtocol(BaseAuthProtocol):
 
     @property
     def _reject_auth_headers(self):
-        header_val = 'Keystone uri=\'%s\'' % self._auth_uri
+        header_val = 'Keystone uri=\'%s\'' % self._www_authenticate_uri
         return [('WWW-Authenticate', header_val)]
 
     def _token_hashes(self, token):
@@ -799,6 +810,13 @@ class AuthProtocol(BaseAuthProtocol):
             self.log.warning('Fetch revocation list failed, '
                              'fallback to online validation.')
         else:
+            self.log.warning('auth_token middleware received a PKI/Z token. '
+                             'This form of token is deprecated and has been '
+                             'removed from keystone server and will be '
+                             'removed from auth_token middleware in the Rocky '
+                             'release. Please contact your administrator '
+                             'about upgrading keystone and the token format.')
+
             data = jsonutils.loads(verified)
 
             audit_ids = None
@@ -939,7 +957,14 @@ class AuthProtocol(BaseAuthProtocol):
             include_service_catalog=self._include_service_catalog,
             requested_auth_version=auth_version)
 
+    def _create_oslo_cache(self):
+        # having this as a function makes test mocking easier
+        region = oslo_cache.create_region()
+        oslo_cache.configure_cache_region(self._conf.oslo_conf_obj, region)
+        return region
+
     def _token_cache_factory(self):
+
         security_strategy = self._conf.get('memcache_security_strategy')
 
         cache_kwargs = dict(
