@@ -19,7 +19,6 @@ import six
 
 from keystonemiddleware.auth_token import _exceptions as exc
 from keystonemiddleware.auth_token import _memcache_crypt as memcache_crypt
-from keystonemiddleware.auth_token import _memcache_pool as memcache_pool
 from keystonemiddleware.i18n import _
 
 
@@ -90,8 +89,11 @@ class _MemcacheClientPool(object):
     """An advanced memcached client pool that is eventlet safe."""
 
     def __init__(self, memcache_servers, **kwargs):
-        self._pool = memcache_pool.MemcacheClientPool(memcache_servers,
-                                                      **kwargs)
+        # NOTE(sileht): This will import python-memcached, we don't want
+        # it as hard dependency, so lazy load it.
+        from oslo_cache import _memcache_pool
+        self._pool = _memcache_pool.MemcacheClientPool(memcache_servers,
+                                                       **kwargs)
 
     @contextlib.contextmanager
     def reserve(self):
